<?php
namespace Claromentis\Mailgun\Model;

$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"] = (@$GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"] ?: array()) + array("_9c050c786fc87170cbb84fc6a8b13" . "cb6" => base64_decode("YXR0YW" . "NobWVu" . "dC0="), "_956cd32298a229f9768f109" . "6f077ace3" => base64_decode("Ym9keS1wbG" . "Fpbg=="), "_6e1c717cf3cbf1af982ed74d" . "4336b7f1" => base64_decode("Ym9" . "keS" . "1od" . "G1s"), "_8c575917cbae" . "df1e7efae8493" . "9402bff" => base64_decode("U3ViamV" . "jdA=="), "_44e986c04f41a08b56a383" . "c7b3a88ee2" => base64_decode("c2" . "Vu" . "ZG" . "Vy"), "_d706c160e45bf7" . "434fff82a5976f0" . "e19" => base64_decode("YXJyYXlfa2V5" . "cw=="), "_f589476007fa133f" . "457c3ef29ddfa566" => base64_decode("VG8" . "="), "_618a4aeb9fecc4592a4521" . "f34876fa29" => base64_decode("ZnJvb" . "Q=="), "_97ea09a7faf27c52c6e" . "ff69773df1d8a" => base64_decode("dGltZXN0YW1" . "w"), "_f39f5346e313" . "e4dd1ac3a7bd8" . "032beda" => base64_decode("c3Vic3RyX2NvbXB" . "hcmU="), "_1d6c68a0262e8fa0bed" . "1215b7224a98e" => base64_decode("cmVjaXBpZW" . "50"), "_a1e707d02a23" . "6dadebd15a45e" . "65ebdb6" => base64_decode("YXR0YWNobW" . "VudC1jb3Vu" . "dA=="));
use Claromentis\Core\Mail\Receive\Contract\MailAttachment;
use Claromentis\Core\Mail\Receive\Contract\MailMessage;
use Claromentis\Core\Util\ArrayUtil;




class MailgunMessage implements MailMessage
{
    protected $message_data;
    protected $attachments_data;
    protected $attachments;
    
    
    
    
    
    public function __construct($_a3d82c5df38e194c9c73e3ccb4223bbc = [], $_4e7ab34a53ffb13eb0838003f33034d4 = [])
    {
        $this->message_data = $_a3d82c5df38e194c9c73e3ccb4223bbc;
        $this->attachments = $_4e7ab34a53ffb13eb0838003f33034d4;
        foreach ($GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_d706c160e45bf7434fff82a5976" . "f0e19"]($this->message_data) as $key) {
            if ($key !== $GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_a1e707d02a236dadebd15" . "a45e65ebdb6"] && $GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_f39f5346e313e4dd1ac3a7" . "bd8032beda"]($key, $GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_9c050c786fc87170cbb84fc6a8" . "b13cb6"], 0, 11) === 0) {
                $this->attachments[] = new MailgunAttachmentString($key, $this->message_data[$key]);
            }
        }
    }
    
    
    
    
    public function GetRecipientAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_1d6c68a0262e8fa" . "0bed1215b7224a98" . "e"]);
    }
    
    
    
    
    
    
    public function GetFrom() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_618a4aeb9fe" . "cc4592a4521f" . "34876fa29"]], null);
    }
    
    
    
    
    
    
    
    public function GetTo() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_f589476007fa133f457c3ef29ddfa" . "566"]], null);
    }
    
    
    
    
    public function GetSubject() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_8c575917cbaedf1e7e" . "fae84939402bff"]);
    }
    
    
    
    
    public function GetBodyHtml() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_6e1c717cf3cbf1af982" . "ed74d4336b7f1"]);
    }
    
    
    
    
    public function GetBodyText() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_956cd32298a22" . "9f9768f1096f07" . "7ace3"]);
    }
    
    
    
    
    public function GetDate() : \Date
    {
        $_67a0d624aebcceb0abd5ce56a53ff06f = new \Date(ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_97ea09a7faf27c52c6eff69773df1d8" . "a"]));
        return $_67a0d624aebcceb0abd5ce56a53ff06f;
    }
    
    
    
    
    public function GetSenderAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_44e986c04f41a08b5" . "6a383c7b3a88ee2"]);
    }
    public function GetAttachments()
    {
        return $this->attachments;
    }
}