<?php
namespace Claromentis\Infocapture\Subscriber;

$GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"] = (@$GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"] ?: array()) + array("_e608e5b5c4c34a67ba97ef8" . "4c1e16199" => base64_decode("Jw" . "=="), "_f656816961e85738" . "06141c558b184fe2" => base64_decode("c3V" . "iam" . "Vjd" . "A=="), "_460e1ae" . "b3113a16" . "76ce59a8" . "f40431d5" . "c" => base64_decode("RmFpbGVkIHRvIHByb2Nlc3MgZW1haWwgZm9yIGlu" . "Zm9jYXB0dXJlIHByb2plY3Q="), "_376d30c40857357a4d4cbb1" . "ffaa25817" => base64_decode("d" . "G" . "8" . "="), "_a3d82c5df3" . "8e194c9c73e" . "3ccb4223bbc" => base64_decode("ZW1haWx" . "fZGF0YQ" . "=="), "_03b1f0cee83" . "5582d1158dce" . "2678b505c" => base64_decode("U3RhcnRpbmcgaW5" . "mb2NhcHR1cmUgbW" . "FpbCByZWNlaXZlZ" . "CBzdWJzY3JpYmVy"), "_5d40a2cf1c52" . "5fb252bf5599e" . "339fdd0" => base64_decode("Tm8gaW5mb2NhcHR1cmUgcHJvamVjdCB3YXMgaWRlbnRpZmllZ" . "CBmb3IgbWFpbDsgc3ViamVjdCAn"), "_c35473364" . "fa7a050299" . "058f332ec2" . "9c1" => base64_decode("ZXhjZXB0aW" . "9u"), "_67a0d624aebcceb0abd5ce56a53ff0" . "6f" => base64_decode("ZGF0" . "ZQ=="), "_ced92d7b" . "391285c8a" . "26846f1f4" . "bd3128" => base64_decode("Ym9" . "keV" . "90Z" . "Xh0"), "_618a4aeb9fecc4592a4521f34" . "876fa29" => base64_decode("ZnJvbQ" . "=="), "_bfda889b74ea561b14325e30" . "e7d75426" => base64_decode("Ym9ke" . "V9odG" . "1s"), "_9b16fa2683095e67d7c8b265a8" . "081d0b" => base64_decode("TWFpbFJlY2VpdmVkRXZlbn" . "RSZWNlaXZlcg=="), "pro" . "jec" . "t_i" . "d" => base64_decode("cHJvamVjd" . "F9pZA=="));
use Claromentis\Core\Event\EventDispatcherInterface;
use Claromentis\Core\Event\EventSubscriberInterface;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEventType;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEvent;
use Claromentis\Infocapture\Model\MailboxMessage;
use Claromentis\Infocapture\UseCase\GetProjectByEmailAddress;
use Claromentis\Infocapture\UseCase\ProcessEmail;
use Exception;
use Psr\Log\LoggerInterface;
class MailReceivedSubscriber implements EventSubscriberInterface
{
    protected $logger;
    protected $get_project_use_case;
    protected $process_email_use_case;
    public function __construct(LoggerInterface $logger, GetProjectByEmailAddress $_ecd19adac06bcc3637cff9925531a823, ProcessEmail $_33929bbf18079cca22e39e6dbe7eea3c)
    {
        $this->logger = $logger;
        $this->get_project_use_case = $_ecd19adac06bcc3637cff9925531a823;
        $this->process_email_use_case = $_33929bbf18079cca22e39e6dbe7eea3c;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function getSubscribedEvents()
    {
        return [
            
            
            ReceiveMailEventType::RECEIVE_MAIL => $GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_9b16fa2683" . "095e67d7c8b" . "265a8081d0b"],
        ];
    }
    
    
    
    
    
    
    public function MailReceivedEventReceiver(ReceiveMailEvent $event, $_5693d84b45564f912e36404cbe8957e8, EventDispatcherInterface $_b497ce6f2af10f67516aed0ecf34d8cf)
    {
        $this->logger->info($GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_03b1f0cee835582d1158d" . "ce2678b505c"]);
        $_a9bf694098bca136cc65bf4d2623bc70 = $event->GetMailMessage();
        $_f656816961e8573806141c558b184fe2 = $_a9bf694098bca136cc65bf4d2623bc70->GetSubject();
        
        
        $project = null;
        if ($_a9bf694098bca136cc65bf4d2623bc70 instanceof MailboxMessage) {
            $project = $_a9bf694098bca136cc65bf4d2623bc70->GetProject();
        } else {
            $project = $this->get_project_use_case->GetMailgunProject($_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress());
        }
        if ($project === null) {
            $this->logger->debug($GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_5d40a2cf1c" . "525fb252bf5" . "599e339fdd0"] . $_f656816961e8573806141c558b184fe2 . $GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_e608e5b5c4c34a67ba97ef84c1e16" . "199"]);
            return;
        }
        $_a3d82c5df38e194c9c73e3ccb4223bbc = [$GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_618a4ae" . "b9fecc45" . "92a4521f" . "34876fa2" . "9"] => $_a9bf694098bca136cc65bf4d2623bc70->GetSenderAddress(), $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_376d30c40857357a4d4cbb1ff" . "aa25817"] => $_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress(), $GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_f656816961e8573806141c558b184" . "fe2"] => $_f656816961e8573806141c558b184fe2, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_ced92d7b391285c8a26846" . "f1f4bd3128"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyText(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_bfda889b" . "74ea561b1" . "4325e30e7" . "d75426"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyHtml(), $GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_67a0d624aebcceb0abd5" . "ce56a53ff06f"] => $_a9bf694098bca136cc65bf4d2623bc70->GetDate()];
        try {
            $this->process_email_use_case->ProcessEmail($project, $_a3d82c5df38e194c9c73e3ccb4223bbc, $_a9bf694098bca136cc65bf4d2623bc70->GetAttachments());
        } catch (Exception $_c35473364fa7a050299058f332ec29c1) {
            $this->logger->warning($GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_460e1aeb3113a1" . "676ce59a8f40431" . "d5c"], [$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["proje" . "ct_id"] => $project->GetId(), $GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_a3d82c5" . "df38e194" . "c9c73e3c" . "cb4223bb" . "c"] => $_a3d82c5df38e194c9c73e3ccb4223bbc, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_c35473364fa7a05" . "0299058f332ec29c" . "1"] => $_c35473364fa7a050299058f332ec29c1]);
        }
    }
}